# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

import os
import sys
sys.path.append(os.path.abspath("./_pygments"))

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'autoray'
copyright = '2019-2023, Johnnie Gray'
author = 'Johnnie Gray'

try:
    from autoray import __version__
    release = __version__
except ImportError:
    try:
        from importlib.metadata import version as _version
        release = _version('autoray')
    except ImportError:
        release = '0.0.0+unknown'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    'myst_nb',
    'sphinx.ext.intersphinx',
    'sphinx.ext.extlinks',
    'sphinx.ext.napoleon',
    'sphinx.ext.linkcode',
    'sphinx_copybutton',
    'autoapi.extension',
]

nb_execution_mode = "off"
myst_heading_anchors = 4
myst_enable_extensions = [
    "amsmath",
    "colon_fence",
    "deflist",
    "dollarmath",
    "html_image",
]

# sphinx-autoapi
autoapi_dirs = ['../autoray']

templates_path = ['_templates']
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store', '**.ipynb_checkpoints']

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = 'furo'

html_theme_options = {
    "sidebar_hide_name": True,
    # "light_css_variables": {
    #     "color-brand-primary": "hsl(72, 75%, 40%)",
    #     "color-brand-content": "hsl(238, 50%, 60%)",
    # },
    # "dark_css_variables": {
    #     "color-brand-primary": "hsl(72, 75%, 60%)",
    #     "color-brand-content": "hsl(238, 75%, 70%)",
    # },
    "light_logo": "autoray-header.png",
    "dark_logo": "autoray-header.png",
}

html_css_files = ["my-styles.css"]
html_static_path = ['_static']
html_favicon = "_static/autoray.ico"

pygments_style = '_pygments_light.MarianaLight'
pygments_dark_style = "_pygments_dark.MarianaDark"


def linkcode_resolve(domain, info):
    """
    Determine the URL corresponding to Python object
    """
    import autoray
    import inspect

    if domain != "py":
        return None

    modname = info["module"]
    fullname = info["fullname"]

    submod = sys.modules.get(modname)
    if submod is None:
        return None

    obj = submod
    for part in fullname.split("."):
        try:
            obj = getattr(obj, part)
        except AttributeError:
            return None

    try:
        fn = inspect.getsourcefile(inspect.unwrap(obj))
    except TypeError:
        fn = None
    if not fn:
        return None

    try:
        source, lineno = inspect.getsourcelines(obj)
    except OSError:
        lineno = None

    if lineno:
        linespec = f"#L{lineno}-L{lineno + len(source) - 1}"
    else:
        linespec = ""

    fn = os.path.relpath(fn, start=os.path.dirname(autoray.__file__))

    if "+" in autoray.__version__:
        return (
            f"https://github.com/jcmgray/autoray/blob/"
            f"HEAD/autoray/{fn}{linespec}"
        )
    else:
        return (
            f"https://github.com/jcmgray/autoray/blob/"
            f"v{autoray.__version__}/autoray/{fn}{linespec}"
        )



from setuptools import setup, find_packages


def readme():
    with open("README.md") as f:
        long_desc = f.read()
        # strip out the raw html images?
        return long_desc


short_desc = "Abstract your array operations."

setup(
    name="autoray",
    description=short_desc,
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="http://github.com/jcmgray/autoray",
    project_urls={  # Optional
        'Bug Reports': 'https://github.com/jcmgray/autoray/issues',
        'Source': 'https://github.com/jcmgray/autoray/',
    },
    author="Johnnie Gray",
    author_email="johnniemcgray@gmail.com",
    license="Apache",
    packages=find_packages(exclude=["deps", "tests*"]),
    extras_require={
        "tests": [
            "numpy",
            "coverage",
            "pytest",
            "pytest-cov",
        ],
        'docs': [
            'sphinx>=2.0',
            'sphinx-autoapi',
            'astroid<3',
            'sphinx-copybutton',
            'myst-nb',
            'furo',
            'setuptools_scm',
            'ipython!=8.7.0',
        ],
    },
    python_requires=">=3.8",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    keywords="array agnostic numeric numpy cupy dask tensorflow jax autograd",
)
